@@ -17,10 +17,11 @@ type KuryrBootstrapResult struct {
 	WebhookCAKey      string
 	WebhookCert       string
 	WebhookKey        string
+	UserCACert        string
 }
 
 type OVNBootstrapResult struct {
-	OVNMasterNodes []string
+	MasterIPs []string
 }
 
 type BootstrapResult struct {
